@@ -4,13 +4,22 @@ from dataclasses import dataclass
 from typing import Any, ClassVar
 
 import anyio
-from pydantic import BaseModel
+import anyio.to_thread
 
-from ._models import Params
 from ._to_list import to_list
-from ._types import T, Unset, not_sentinel
 from .concurrency import Lock as ConcurrencyLock
-from .concurrency import Semaphore, create_task_group, is_coro_func
+from .concurrency import (
+    Semaphore,
+    create_task_group,
+    get_cancelled_exc_class,
+    is_coro_func,
+    move_on_after,
+)
+from .types import Params, T, Unset, not_sentinel
+
+_INITIALIZED = False
+_MODEL_LIKE = None
+
 
 __all__ = (
     "alcall",
@@ -34,7 +43,7 @@ async def alcall(
     output_unique: bool = False,
     output_flatten_tuple_set: bool = False,
     delay_before_start: float = 0,
-    retry_initial_deplay: float = 0,
+    retry_initial_delay: float = 0,
     retry_backoff: float = 1,
     retry_default: Any = Unset,
     retry_timeout: float = None,
@@ -48,6 +57,14 @@ async def alcall(
     retries, timeout, and output processing.
     """
 
+    global _INITIALIZED, _MODEL_LIKE
+    if _INITIALIZED is False:
+        from msgspec import Struct
+        from pydantic import BaseModel
+
+        _MODEL_LIKE = (BaseModel, Struct)
+        _INITIALIZED = True
+
     # Validate func is a single callable
     if not callable(func):
         # If func is not callable, maybe it's an iterable. Extract one callable if possible.
@@ -76,7 +93,7 @@ async def alcall(
     else:
         if not isinstance(input_, list):
             # Attempt to iterate
-            if isinstance(input_, BaseModel):
+            if isinstance(input_, _MODEL_LIKE):
                 # Pydantic model, convert to list
                 input_ = [input_]
             else:
@@ -100,7 +117,7 @@ async def alcall(
         if coro_func:
             # Async function
             if retry_timeout is not None:
-                with anyio.move_on_after(retry_timeout) as cancel_scope:
+                with move_on_after(retry_timeout) as cancel_scope:
                     result = await func(item, **kwargs)
                 if cancel_scope.cancelled_caught:
                     raise asyncio.TimeoutError(
@@ -112,7 +129,7 @@ async def alcall(
         else:
             # Sync function
             if retry_timeout is not None:
-                with anyio.move_on_after(retry_timeout) as cancel_scope:
+                with move_on_after(retry_timeout) as cancel_scope:
                     result = await anyio.to_thread.run_sync(
                         func, item, **kwargs
                     )
@@ -126,14 +143,14 @@ async def alcall(
 
     async def execute_task(i: Any, index: int) -> Any:
         attempts = 0
-        current_delay = retry_initial_deplay
+        current_delay = retry_initial_delay
         while True:
             try:
                 result = await call_func(i)
                 return index, result
 
             # if cancelled, re-raise
-            except anyio.get_cancelled_exc_class():
+            except get_cancelled_exc_class():
                 raise
 
             # handle other exceptions
@@ -172,7 +189,7 @@ async def alcall(
     # Execute all tasks using task group
     async with create_task_group() as tg:
         for idx, item in enumerate(input_):
-            await tg.start_soon(run_and_store, item, idx)
+            tg.start_soon(run_and_store, item, idx)
             # Apply throttle delay between starting tasks
             if throttle_delay and idx < len(input_) - 1:
                 await anyio.sleep(throttle_delay)
@@ -206,10 +223,10 @@ async def bcall(
     output_unique: bool = False,
     output_flatten_tuple_set: bool = False,
     delay_before_start: float = 0,
-    retry_initial_deplay: float = 0,
+    retry_initial_delay: float = 0,
     retry_backoff: float = 1,
     retry_default: Any = Unset,
-    retry_timeout: float = 0,
+    retry_timeout: float = None,
     retry_attempts: int = 0,
     max_concurrent: int | None = None,
     throttle_period: float | None = None,
@@ -231,7 +248,7 @@ async def bcall(
             output_unique=output_unique,
             output_flatten_tuple_set=output_flatten_tuple_set,
             delay_before_start=delay_before_start,
-            retry_initial_deplay=retry_initial_deplay,
+            retry_initial_delay=retry_initial_delay,
             retry_backoff=retry_backoff,
             retry_default=retry_default,
             retry_timeout=retry_timeout,
@@ -262,7 +279,7 @@ class AlcallParams(Params):
 
     # retry and timeout
     delay_before_start: float
-    retry_initial_deplay: float
+    retry_initial_delay: float
     retry_backoff: float
     retry_default: Any
     retry_timeout: float
@@ -291,6 +308,4 @@ class BcallParams(AlcallParams):
         self, input_: list[Any], func: Callable[..., T], **kw
     ) -> list[T]:
         kwargs = {**self.default_kw(), **kw}
-        func = self._func
-
-        return await func(input_, func, self.batch_size, **kwargs)
+        return await bcall(input_, func, self.batch_size, **kwargs)
