@@ -18,14 +18,13 @@ from functools import wraps
 from pathlib import Path
 from typing import Any, ClassVar, Generic, Literal, TypeVar
 
-import pandas as pd
-from pydantic import Field, field_serializer, field_validator, model_validator
+from pydantic import Field, field_serializer
 from pydantic.fields import FieldInfo
 from pydapter import Adaptable, AsyncAdaptable
 from typing_extensions import Self, deprecated, override
 
 from lionagi._errors import ItemExistsError, ItemNotFoundError, ValidationError
-from lionagi.libs.concurrency import Lock as ConcurrencyLock
+from lionagi.ln.concurrency import Lock as ConcurrencyLock
 from lionagi.utils import (
     UNDEFINED,
     is_same_dtype,
@@ -988,6 +987,12 @@ class Pile(Element, Collective[T], Generic[T], Adaptable, AsyncAdaptable):
             is_same_dtype(self.collections.values())
         )
 
+    @classmethod
+    def list_adapters(cls) -> list[str]:
+        syn_ = cls._adapter_registry._reg.keys()
+        asy_ = cls._async_registry._reg.keys()
+        return list(set(syn_) | set(asy_))
+
     def adapt_to(self, obj_key: str, many=False, **kw: Any) -> Any:
         """Adapt to another format.
 
@@ -1041,11 +1046,14 @@ class Pile(Element, Collective[T], Generic[T], Adaptable, AsyncAdaptable):
         kw["adapt_meth"] = "from_dict"
         return await super().adapt_from_async(obj, obj_key, many=many, **kw)
 
-    def to_df(
-        self, columns: list[str] | None = None, **kw: Any
-    ) -> pd.DataFrame:
+    def to_df(self, columns: list[str] | None = None, **kw: Any):
         """Convert to DataFrame."""
-        from pydapter.extras.pandas_ import DataFrameAdapter
+        try:
+            from pydapter.extras.pandas_ import DataFrameAdapter
+        except ImportError as e:
+            raise ImportError(
+                "pandas is required for to_df(). Please install it via `pip install pandas`."
+            ) from e
 
         df = DataFrameAdapter.to_obj(
             list(self.collections.values()), adapt_meth="to_dict", **kw
@@ -1132,6 +1140,55 @@ class Pile(Element, Collective[T], Generic[T], Adaptable, AsyncAdaptable):
     ) -> None:
         return self.dump(fp, obj_key=obj_key, mode=mode, clear=clear, **kw)
 
+    def filter_by_type(
+        self,
+        item_type: type[T] | list | set,
+        strict_type: bool = False,
+        as_pile: bool = False,
+        reverse: bool = False,
+        num_items: int | None = None,
+    ) -> list[T]:
+        if isinstance(item_type, type):
+            if is_union_type(item_type):
+                item_type = set(union_members(item_type))
+            else:
+                item_type = {item_type}
+
+        if isinstance(item_type, list | tuple):
+            item_type = set(item_type)
+
+        if not isinstance(item_type, set):
+            raise TypeError("item_type must be a type or a list/set of types")
+
+        meth = None
+
+        if strict_type:
+            meth = lambda item: type(item) in item_type
+        else:
+            meth = (
+                lambda item: any(isinstance(item, t) for t in item_type)
+                is True
+            )
+
+        out = []
+        prog = (
+            list(self.progression)
+            if not reverse
+            else reversed(list(self.progression))
+        )
+        for i in prog:
+            item = self.collections[i]
+            if meth(item):
+                out.append(item)
+            if num_items is not None and len(out) == num_items:
+                break
+
+        if as_pile:
+            return self.__class__(
+                collections=out, item_type=item_type, strict_type=strict_type
+            )
+        return out
+
 
 def to_list_type(value: Any, /) -> list[Any]:
     """Convert input to a list format"""
@@ -1152,11 +1209,10 @@ def to_list_type(value: Any, /) -> list[Any]:
 
 if not _ADAPATER_REGISTERED:
     from pydapter.adapters import CsvAdapter, JsonAdapter
-    from pydapter.extras.pandas_ import DataFrameAdapter
 
     Pile.register_adapter(CsvAdapter)
     Pile.register_adapter(JsonAdapter)
-    Pile.register_adapter(DataFrameAdapter)
+
     _ADAPATER_REGISTERED = True
 
 Pile = Pile
