@@ -3,7 +3,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from collections import deque
-from typing import Any, Literal
+from typing import Any, Generic, Literal, TypeVar
 
 from pydantic import Field, field_serializer, field_validator, model_validator
 from typing_extensions import Self
@@ -17,11 +17,15 @@ from ..generic.pile import Pile
 from .edge import Edge
 from .node import Node
 
+T = TypeVar("T", bound=Node)
+
+_NETWORKX_AVAILABLE = None
+_MATPLIB_AVAILABLE = None
 __all__ = ("Graph",)
 
 
-class Graph(Element, Relational):
-    internal_nodes: Pile[Node] = Field(
+class Graph(Element, Relational, Generic[T]):
+    internal_nodes: Pile[T] = Field(
         default_factory=lambda: Pile(item_type={Node}, strict_type=False),
         title="Internal Nodes",
         description="A collection of nodes in the graph.",
@@ -81,8 +85,7 @@ class Graph(Element, Relational):
             or edge.tail not in self.internal_nodes
         ):
             raise RelationError(
-                "Failed to add edge: Either edge head or tail node does"
-                " not exist in the graph."
+                "Failed to add edge: Either edge head or tail node does not exist in the graph."
             )
         try:
             self.internal_edges.insert(len(self.internal_edges), edge)
@@ -214,13 +217,19 @@ class Graph(Element, Relational):
 
     def to_networkx(self, **kwargs) -> Any:
         """Convert the graph to a NetworkX graph object."""
-        try:
-            from networkx import DiGraph  # type: ignore
+        global _NETWORKX_AVAILABLE
+        if _NETWORKX_AVAILABLE is None:
+            from lionagi.ln import is_import_installed
 
-        except ImportError:
-            from lionagi.libs.package.imports import check_import
+            _NETWORKX_AVAILABLE = is_import_installed("networkx")
 
-            DiGraph = check_import("networkx", import_name="DiGraph")
+        if _NETWORKX_AVAILABLE is not True:
+            raise ImportError(
+                "The 'networkx' package is required for this feature. "
+                "Please install `networkx` or `'lionagi[graph]'`."
+            )
+
+        from networkx import DiGraph  # type: ignore
 
         g = DiGraph(**kwargs)
         for node in self.internal_nodes:
@@ -245,20 +254,23 @@ class Graph(Element, Relational):
         **kwargs,
     ):
         """Display the graph using NetworkX and Matplotlib."""
-
-        try:
-            import matplotlib.pyplot as plt  # type: ignore
-            import networkx as nx  # type: ignore
-        except ImportError:
-            from lionagi.libs.package.imports import check_import
-
-            check_import("matplotlib")
-            check_import("networkx")
-
-            import matplotlib.pyplot as plt  # type: ignore
-            import networkx as nx  # type: ignore
-
         g = self.to_networkx(**kwargs)
+
+        global _MATPLIB_AVAILABLE
+        if _MATPLIB_AVAILABLE is None:
+            from lionagi.ln import is_import_installed
+
+            _MATPLIB_AVAILABLE = is_import_installed("matplotlib")
+
+        if _MATPLIB_AVAILABLE is not True:
+            raise ImportError(
+                "The 'matplotlib' package is required for this feature. "
+                "Please install `matplotlib` or `'lionagi[graph]'`."
+            )
+
+        import matplotlib.pyplot as plt  # type: ignore
+        import networkx as nx  # type: ignore
+
         pos = nx.spring_layout(g)
         nx.draw(
             g,
