@@ -4,10 +4,10 @@
 
 from __future__ import annotations
 
-import json
 from typing import Any
 
-from pydantic import field_validator
+import orjson
+from pydantic import BaseModel, field_serializer, field_validator
 from pydapter import Adaptable, AsyncAdaptable
 
 from lionagi._class_registry import LION_CLASS_REGISTRY
@@ -44,7 +44,7 @@ class Node(Element, Relational, AsyncAdaptable, Adaptable):
             return None
         if isinstance(value, str):
             try:
-                loaded = json.loads(value)
+                loaded = orjson.loads(value)
                 if not isinstance(loaded, list):
                     raise ValueError
                 return [float(x) for x in loaded]
@@ -62,7 +62,12 @@ class Node(Element, Relational, AsyncAdaptable, Adaptable):
     async def adapt_to_async(
         self, obj_key: str, many=False, **kwargs: Any
     ) -> Any:
+        # Only register postgres adapter if this specific operation needs it
+        if obj_key == "lionagi_async_pg":
+            _ensure_postgres_adapter()
+
         kwargs["adapt_meth"] = "to_dict"
+        kwargs["adapt_kw"] = {"mode": "db"}
         return await super().adapt_to_async(
             obj_key=obj_key, many=many, **kwargs
         )
@@ -75,6 +80,10 @@ class Node(Element, Relational, AsyncAdaptable, Adaptable):
         many=False,
         **kwargs: Any,
     ) -> Node:
+        # Only register postgres adapter if this specific operation needs it
+        if obj_key == "lionagi_async_pg":
+            _ensure_postgres_adapter()
+
         kwargs["adapt_meth"] = "from_dict"
         return await super().adapt_from_async(
             obj, obj_key=obj_key, many=many, **kwargs
@@ -85,6 +94,7 @@ class Node(Element, Relational, AsyncAdaptable, Adaptable):
         Convert this Node to another format using a registered adapter.
         """
         kwargs["adapt_meth"] = "to_dict"
+        kwargs["adapt_kw"] = {"mode": "db"}
         return super().adapt_to(obj_key=obj_key, many=many, **kwargs)
 
     @classmethod
@@ -103,23 +113,48 @@ class Node(Element, Relational, AsyncAdaptable, Adaptable):
         kwargs["adapt_meth"] = "from_dict"
         return super().adapt_from(obj, obj_key=obj_key, many=many, **kwargs)
 
+    @field_serializer("content")
+    def _serialize_content(self, value: Any) -> Any:
+        if isinstance(value, Element):
+            return value.to_dict()
+        if isinstance(value, BaseModel):
+            return value.model_dump()
+        return value
+
+    @field_validator("content", mode="before")
+    def _validate_content(cls, value: Any) -> Any:
+        if isinstance(value, dict) and "lion_class" in value.get(
+            "metadata", {}
+        ):
+            return Element.from_dict(value)
+        return value
+
+
+def _ensure_postgres_adapter():
+    """Lazy registration of postgres adapter when needed"""
+    if not hasattr(Node, "_postgres_adapter_checked"):
+        from lionagi.adapters._utils import check_async_postgres_available
+
+        if check_async_postgres_available() is True:
+            try:
+                from lionagi.adapters.async_postgres_adapter import (
+                    LionAGIAsyncPostgresAdapter,
+                )
+
+                Node.register_async_adapter(LionAGIAsyncPostgresAdapter)
+            except ImportError:
+                pass  # Graceful degradation if postgres dependencies missing
+        Node._postgres_adapter_checked = True
+
 
 if not _ADAPATER_REGISTERED:
     from pydapter.adapters import JsonAdapter, TomlAdapter
-    from pydapter.extras.pandas_ import SeriesAdapter
 
     Node.register_adapter(JsonAdapter)
     Node.register_adapter(TomlAdapter)
-    Node.register_adapter(SeriesAdapter)
 
-    from lionagi.adapters._utils import check_async_postgres_available
-
-    if check_async_postgres_available() is True:
-        from lionagi.adapters.async_postgres_adapter import (
-            LionAGIAsyncPostgresAdapter,
-        )
-
-        Node.register_async_adapter(LionAGIAsyncPostgresAdapter)
+    # PostgreSQL adapter registration is now lazy - only loaded when needed
+    # Call _ensure_postgres_adapter() in methods that actually use async adapters
 
     _ADAPATER_REGISTERED = True
 
