@@ -4,13 +4,14 @@
 
 from __future__ import annotations
 
-import json
 from pathlib import Path
 from typing import Any
 
 from jinja2 import Environment, FileSystemLoader, Template
 from pydantic import Field, PrivateAttr, field_serializer
 
+from lionagi import ln
+
 from .._concepts import Sendable
 from ..generic.element import Element, IDType
 from ..generic.log import Log
@@ -114,7 +115,14 @@ class RoledMessage(Node, Sendable):
             if isinstance(self.template, Template):
                 return self.template.render(**self.content)
         except Exception:
-            return json.dumps(self.content)
+            return ln.json_dumps(
+                self.content,
+                pretty=True,
+                sort_keys=True,
+                append_newline=True,
+                deterministic_sets=True,
+                decimal_as_float=True,
+            )
 
     @classmethod
     def create(cls, **kwargs):
@@ -239,10 +247,7 @@ class RoledMessage(Node, Sendable):
             if len(str(self.content)) > 75
             else str(self.content)
         )
-        return (
-            f"Message(role={self.role}, sender={self.sender}, "
-            f"content='{content_preview}')"
-        )
+        return f"Message(role={self.role}, sender={self.sender}, content='{content_preview}')"
 
 
 # File: lionagi/protocols/messages/message.py
