@@ -2,20 +2,10 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from ._concepts import (
-    Collective,
-    Communicatable,
-    Condition,
-    Manager,
-    Observable,
-    Observer,
-    Ordering,
-    Relational,
-    Sendable,
-)
-from .action.manager import ActionManager, FunctionCalling, Tool, ToolRef
-from .forms.flow import FlowDefinition, FlowStep
-from .forms.report import BaseForm, Form, Report
+from ._concepts import Collective, Communicatable, Condition, Manager
+from ._concepts import Observable as LegacyObservable
+from ._concepts import Observer, Ordering, Relational, Sendable
+from .contracts import Observable, ObservableProto
 from .generic.element import ID, Element, IDError, IDType, validate_order
 from .generic.event import Event, EventStatus, Execution
 from .generic.log import (
@@ -30,6 +20,7 @@ from .generic.processor import Executor, Processor
 from .generic.progression import Progression, prog
 from .graph.edge import EdgeCondition
 from .graph.graph import Edge, Graph, Node
+from .ids import canonical_id, to_uuid
 from .mail.exchange import Exchange, Mail, Mailbox, Package, PackageCategory
 from .mail.manager import MailManager
 from .messages.base import (
@@ -49,18 +40,21 @@ from .messages.manager import (
     SenderRecipient,
     System,
 )
-from .operatives.step import Operative, Step, StepModel
 
 __all__ = (
     "Collective",
     "Communicatable",
     "Condition",
     "Manager",
-    "Observable",
+    "Observable",  # V1 Protocol (preferred)
+    "ObservableProto",  # Explicit V1 Protocol name
+    "LegacyObservable",  # V0 ABC (deprecated)
     "Observer",
     "Ordering",
     "Relational",
     "Sendable",
+    "canonical_id",  # V0/V1 bridge utility
+    "to_uuid",  # ID conversion utility
     "ID",
     "Element",
     "IDError",
@@ -100,18 +94,6 @@ __all__ = (
     "RoledMessage",
     "SenderRecipient",
     "System",
-    "FlowDefinition",
-    "FlowStep",
-    "BaseForm",
-    "Form",
-    "Report",
-    "Operative",
-    "Step",
-    "StepModel",
-    "ActionManager",
-    "Tool",
-    "FunctionCalling",
-    "ToolRef",
     "MailManager",
     "DataLogger",
     "DataLoggerConfig",
