@@ -1,6 +1,5 @@
 from .anthropic_ import AnthropicMessagesEndpoint
-from .claude_code_ import ClaudeCodeEndpoint, ClaudeCodeRequest
-from .claude_code_cli import ClaudeCodeCLIEndpoint
+from .claude_code_cli import ClaudeCodeCLIEndpoint, ClaudeCodeRequest
 from .exa_ import ExaSearchEndpoint, ExaSearchRequest
 from .oai_ import (
     GroqChatEndpoint,
@@ -14,7 +13,6 @@ from .perplexity_ import PerplexityChatEndpoint, PerplexityChatRequest
 
 __all__ = (
     "AnthropicMessagesEndpoint",
-    "ClaudeCodeEndpoint",
     "ClaudeCodeRequest",
     "ClaudeCodeCLIEndpoint",
     "ExaSearchEndpoint",
